GroupDifference

Struct GroupDifference 

pub struct GroupDifference {
    pub lz_matches: i64,
    pub entropy: f64,
    pub estimated_size: i64,
    pub zstd_size: i64,
    pub original_size: i64,
}
Represents the difference between 2 groups of fields. For the raw values of a single group, see GroupComparisonMetrics.

This can be used for representing the difference between either splits, or any two arbitrary groups of analyzed bytes. Usually this is the difference between a result and a baseline.

Fields

lz_matches: i64

The difference in LZ matches.

entropy: f64

The difference in entropy

estimated_size: i64

Difference in estimated size using the user provided estimate function.

zstd_size: i64

Difference in zstd compressed size

original_size: i64

Difference in original size

Implementations

Source

impl GroupDifference

pub fn from_metrics( baseline: &GroupComparisonMetrics, comparison: &GroupComparisonMetrics, ) -> Self

Creates a new GroupDifference by comparing two sets of metrics

Arguments
  • baseline - The baseline metrics to compare against
  • comparison - The metrics to compare with the baseline
Returns

A new GroupDifference containing the calculated differences