Structs
- Analysis
Results - Final computed metrics for output
Functions
- compute_
analysis_ results - Given a
SchemaAnalyzerwhich has ingested all of the data to be calculated, via theSchemaAnalyzer::add_entryfunction, compute the analysis results.
SchemaAnalyzer which has ingested all of the data to be calculated, via
the SchemaAnalyzer::add_entry function, compute the analysis results.