AnalysisResults

Struct AnalysisResults 

pub struct AnalysisResults {
    pub schema_metadata: Metadata,
    pub file_entropy: f64,
    pub file_lz_matches: u64,
    pub zstd_file_size: u64,
    pub original_size: u64,
    pub per_field: AHashMap<String, FieldMetrics>,
    pub split_comparisons: Vec<SplitComparisonResult>,
    pub custom_comparisons: Vec<GroupComparisonResult>,
}
Final computed metrics for output

Fields

schema_metadata: Metadata

Schema name

file_entropy: f64

Entropy of the whole file

file_lz_matches: u64

LZ compression matches in the file

zstd_file_size: u64

Actual size of the compressed data when compressed with zstandard

original_size: u64

Original size of the uncompressed data

per_field: AHashMap<String, FieldMetrics>

Field path → computed metrics This is a map of full_path to FieldMetrics, such that we can easily merge the results of different fields down the road.

split_comparisons: Vec<SplitComparisonResult>

Split comparison results

custom_comparisons: Vec<GroupComparisonResult>

Custom group comparison results from schema-defined comparisons

Implementations

Source

impl AnalysisResults

pub fn as_field_metrics(&self) -> FieldMetrics

Converts the file level statistics into a FieldMetrics object which can be used for comparison with parent in places such as the print function.

pub fn print<W: Write>( &self, writer: &mut W, schema: &Schema, format: PrintFormat, skip_misc_stats: bool, ) -> Result<()>