pub fn size_estimate(params: SizeEstimationParameters<'_>) -> usizeExpand description
Estimate size of a compressed data based on precalculated LZ matches and entropy
Arguments
params-SizeEstimationParameterscontaining:data_len- The uncompressed data lengthnum_lz_matches- The number of LZ matchesentropy- The estimated entropy of the datalz_match_multiplier- Multiplier for LZ matchesentropy_multiplier- Multiplier for entropy
Returns
This is a rough estimation based on very limited testing on DXT1, only, you’ll want to replace this function with something more suitable for your use case, possibly.