pub fn make_split_comparison_result(
name: String,
description: String,
baseline_bytes: &[u8],
split_bytes: &[u8],
baseline_comparison_metrics: Vec<FieldComparisonMetrics>,
split_comparison_metrics: Vec<FieldComparisonMetrics>,
compression_options: CompressionOptions,
compression_estimation_group_1: Option<CompressionEstimationParams>,
compression_estimation_group_2: Option<CompressionEstimationParams>,
) -> SplitComparisonResultExpand description
Calculates the compression statistics of two splits (of the same data) and
returns them as a SplitComparisonResult object. This can also be used for
generic two-way compares.
This function aggregates the comparison results for individual fields and calculates overall statistics for the split comparison.
Arguments
name- The name of the group comparison.description- A description of the group comparison.baseline_bytes- The bytes of the baseline (original/reference) group.split_bytes- The bytes of the second (comparison) group.baseline_comparison_metrics- The metrics for the individual fields in the baseline (original/reference) group.split_comparison_metrics- The metrics for the individual fields in the second (comparison) group.compression_options- Compression options, zstd compression level, etc.
Returns
A SplitComparisonResult struct containing the aggregated comparison results
and overall statistics.